==> midgard2-core_9.03.0-5.tar.gz: midgard2-core-9.03.0/src/midgard.h <==
/* 
 * Midgard core, API headers.
 *
 * Copyright (C) 2006, 2007, 2008 Piotr Pokora <piotrek.pokora@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _MIDGARD_API_H_
#define _MIDGARD_API_H_

#include <glib.h>
#include <glib-object.h>

#include <midgard/midgard_error.h>
#include <midgard/midgard_type.h>
#include <midgard/midgard_config.h>
#include <midgard/midgard_schema.h>
#include <midgard/midgard_connection.h>
#include <midgard/midgard_metadata.h>
#include <midgard/midgard_object.h>
#include <midgard/midgard_object_class.h>
#include <midgard/midgard_quota.h>
#include <midgard/midgard_reflection_property.h>
#include <midgard/midgard_collector.h>
#include <midgard/midgard_object_parameter.h>
#include <midgard/midgard_object_attachment.h>
#include <midgard/midgard_request_config.h>
#include <midgard/midgard_blob.h>
#include <midgard/midgard_replicator.h>
#include <midgard/midgard_datatypes.h>
#include <midgard/midgard_user.h>
#include <midgard/midgard_sitegroup.h>
#include <midgard/guid.h>
#include <midgard/uuid.h>
#include <midgard/midgard_utils.h>
#include <midgard/midgard_dbus.h>
#include <midgard/midgard_timestamp.h>

#endif /* _MIDGARD_API_H_ */

==> midgard2-core_9.09.1.orig.tar.gz: midgard2-core-9.09.1/src/midgard.h <==
/* 
 * Midgard core, API headers.
 *
 * Copyright (C) 2006, 2007, 2008 Piotr Pokora <piotrek.pokora@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _MIDGARD_API_H_
#define _MIDGARD_API_H_

#include <glib.h>
#include <glib-object.h>

#include <midgard/midgard_error.h>
#include <midgard/midgard_type.h>
#include <midgard/midgard_config.h>
#include <midgard/midgard_schema.h>
#include <midgard/midgard_connection.h>
#include <midgard/midgard_metadata.h>
#include <midgard/midgard_object.h>
#include <midgard/midgard_object_class.h>
#include <midgard/midgard_quota.h>
#include <midgard/midgard_reflection_property.h>
#include <midgard/midgard_collector.h>
#include <midgard/midgard_object_parameter.h>
#include <midgard/midgard_object_attachment.h>
#include <midgard/midgard_blob.h>
#include <midgard/midgard_replicator.h>
#include <midgard/midgard_datatypes.h>
#include <midgard/midgard_user.h>
#include <midgard/guid.h>
#include <midgard/uuid.h>
#include <midgard/midgard_utils.h>
#include <midgard/midgard_dbus.h>
#include <midgard/midgard_storage.h>
#include <midgard/midgard_timestamp.h>
#include <midgard/midgard_transaction.h>
#include <midgard/midgard_view.h>
#include <midgard/midgard_key_config_common.h>

#endif /* _MIDGARD_API_H_ */
